@@ -8,16 +8,14 @@ from typing import List, Dict, Any, Optional, Union
 from dotenv import load_dotenv
 
 from .agents.agent import MCPAgent
-from .agents.swarm_manager import SwarmManager
-from .agents.adaptive_swarm_manager import AdaptiveSwarmManager
 from .auth import call_mcpauth_login, get_available_servers, get_servers_by_client, McpAuthClient, McpAuthError
-from .mcp_client import MCPDirectClient
+from .utils.mcp_client import MCPDirectClient
 
 # Load environment variables
 load_dotenv()
 
 __all__ = [
-    "chat_with_tools", "chat_with_tools_stream", "MCPAgent", "SwarmManager", "AdaptiveSwarmManager", "list_tools", "get_tool_info", "filter_tools", "execute_tool",
+    "chat_with_tools", "chat_with_tools_stream", "MCPAgent", "list_tools", "get_tool_info", "filter_tools", "execute_tool",
     "call_mcpauth_login", "get_available_servers", "get_servers_by_client", "McpAuthClient", "McpAuthError",
     "clear_session", "clear_all_sessions", "list_sessions", "get_conversation_history", "reset_conversation_history"
 ]
@@ -233,6 +231,8 @@ async def _chat_with_tools_async(
     sync_tools: bool = False,
     custom_tools: Optional[List[Dict[str, Any]]] = None,
     custom_tool_handler: Optional[callable] = None,
+    expand_by_server: bool = False,
+    server_access: Optional[List[str]] = None,
     **provider_kwargs
 ) -> Dict[str, Any]:
     """
@@ -259,7 +259,9 @@ async def _chat_with_tools_async(
             max_tools=max_tools,
             min_score=min_score,
             custom_tools=custom_tools,
-            custom_tool_handler=custom_tool_handler
+            custom_tool_handler=custom_tool_handler,
+            expand_by_server=expand_by_server,
+            server_access=server_access
         )
         
         return result
@@ -279,6 +281,8 @@ def chat_with_tools(
     sync_tools: bool = False,
     custom_tools: Optional[List[Dict[str, Any]]] = None,
     custom_tool_handler: Optional[callable] = None,
+    expand_by_server: bool = False,
+    server_access: Optional[List[str]] = None,
     **provider_kwargs
 ) -> Dict[str, Any]:
     """
@@ -297,6 +301,8 @@ def chat_with_tools(
         filter_type: Tool filter type ("bm25", "local_embedding", "cloud")
         enable_filtering: Whether to enable tool filtering (default: True)
         sync_tools: Whether to clear caches and sync tools (default: False)
+        expand_by_server: If True, include all tools from same server when a tool is selected (default: False)
+        server_access: List of server names to allow access to (e.g., ['gmail', 'googlecalendar']). Overrides filtering.
         **provider_kwargs: Additional arguments for the LLM provider
     
     Returns:
@@ -336,6 +342,8 @@ def chat_with_tools(
         sync_tools=sync_tools,
         custom_tools=custom_tools,
         custom_tool_handler=custom_tool_handler,
+        expand_by_server=expand_by_server,
+        server_access=server_access,
         **provider_kwargs
     ))
 
@@ -356,6 +364,8 @@ async def _chat_with_tools_stream_async(
     system_prompt: Optional[str] = None,
     custom_tools: Optional[List[Dict[str, Any]]] = None,
     custom_tool_handler: Optional[callable] = None,
+    expand_by_server: bool = False,
+    server_access: Optional[List[str]] = None,
     **provider_kwargs
 ):
     """
@@ -383,7 +393,9 @@ async def _chat_with_tools_stream_async(
         max_tools=max_tools,
         min_score=min_score,
         custom_tools=custom_tools,
-        custom_tool_handler=custom_tool_handler
+        custom_tool_handler=custom_tool_handler,
+        expand_by_server=expand_by_server,
+        server_access=server_access
     ):
         # Add session_id to metadata chunks
         if chunk.get("type") == "done":
@@ -409,6 +421,8 @@ def chat_with_tools_stream(
     system_prompt: Optional[str] = None,
     custom_tools: Optional[List[Dict[str, Any]]] = None,
     custom_tool_handler: Optional[callable] = None,
+    expand_by_server: bool = False,
+    server_access: Optional[List[str]] = None,
     **provider_kwargs
 ):
     """
@@ -431,6 +445,8 @@ def chat_with_tools_stream(
         sync_tools: Whether to clear caches and sync tools (default: False)
         session_id: Optional session ID for conversation history (auto-generated if not provided)
         system_prompt: Custom system prompt (uses default if not provided)
+        expand_by_server: If True, include all tools from same server when a tool is selected (default: False)
+        server_access: List of server names to allow access to (e.g., ['gmail', 'googlecalendar']). Overrides filtering.
         **provider_kwargs: Additional arguments for the LLM provider
     
     Returns:
@@ -481,6 +497,8 @@ def chat_with_tools_stream(
         system_prompt=system_prompt,
         custom_tools=custom_tools,
         custom_tool_handler=custom_tool_handler,
+        expand_by_server=expand_by_server,
+        server_access=server_access,
         **provider_kwargs
     )
 
