@@ -353,6 +353,46 @@ class GeminiProvider(LLMProvider):
             if key == "required":
                 continue
             
+            # Special handling for 'format' field - Gemini only supports 'enum' and 'date-time'
+            if key == "format":
+                if value in ["enum", "date-time"]:
+                    cleaned[key] = value
+                else:
+                    # Convert unsupported formats to pattern or description
+                    logger.debug(f"Converting unsupported format '{value}' for Gemini")
+                    
+                    # Convert common formats to patterns
+                    if value == "uri" or value == "url":
+                        # Add a pattern for URL validation instead
+                        cleaned["pattern"] = "^https?://"
+                        # Preserve existing description or use from schema
+                        if "description" not in cleaned and "description" in schema:
+                            cleaned["description"] = schema["description"]
+                        elif "description" not in cleaned:
+                            cleaned["description"] = "A valid URL"
+                    elif value == "email":
+                        cleaned["pattern"] = "^[^@]+@[^@]+\\.[^@]+$"
+                        if "description" not in cleaned and "description" in schema:
+                            cleaned["description"] = schema["description"]
+                        elif "description" not in cleaned:
+                            cleaned["description"] = "A valid email address"
+                    elif value == "uuid":
+                        cleaned["pattern"] = "^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$"
+                        if "description" not in cleaned and "description" in schema:
+                            cleaned["description"] = schema["description"]
+                        elif "description" not in cleaned:
+                            cleaned["description"] = "A valid UUID"
+                    else:
+                        # For other formats, just add to description
+                        existing_desc = cleaned.get("description") or schema.get("description", "")
+                        if existing_desc:
+                            cleaned["description"] = f"{existing_desc} (format: {value})"
+                        else:
+                            cleaned["description"] = f"Value with format: {value}"
+                    
+                    # Don't include the unsupported format field
+                    continue
+            
             # Recursively clean nested objects
             if isinstance(value, dict):
                 cleaned[key] = self._clean_schema_for_gemini(value)
